// generated from rosidl_generator_c/resource/idl__description.c.em
// with input from control_msgs:action/ExecuteMotionPrimitiveSequence.idl
// generated code does not contain a copyright notice

#include "control_msgs/action/detail/execute_motion_primitive_sequence__functions.h"

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence__get_type_hash(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xe3, 0xa5, 0x7a, 0xb1, 0x73, 0x77, 0xb5, 0x92,
      0x17, 0x90, 0xc8, 0xc8, 0xdd, 0x6e, 0x13, 0x04,
      0x36, 0xae, 0xca, 0xf2, 0xc9, 0x13, 0x69, 0xf4,
      0x89, 0x54, 0x82, 0x7e, 0xcb, 0x9b, 0x45, 0xb2,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xf1, 0x17, 0x23, 0x4a, 0x26, 0x3c, 0x02, 0xed,
      0x55, 0xf3, 0x79, 0x9a, 0x4a, 0x54, 0x83, 0x51,
      0x29, 0x3b, 0x38, 0x2b, 0x5c, 0x15, 0x5c, 0x24,
      0xa6, 0x03, 0x65, 0x48, 0xe5, 0xd8, 0x46, 0xc6,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xc9, 0x5c, 0xba, 0xea, 0xf3, 0xf3, 0x54, 0x74,
      0xf7, 0x31, 0xa9, 0xab, 0x32, 0x3e, 0xd0, 0x38,
      0x78, 0x97, 0x8f, 0x3c, 0x54, 0xf9, 0x07, 0x33,
      0x29, 0x70, 0xb7, 0x86, 0xc0, 0x3f, 0x60, 0x49,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x39, 0xb9, 0x14, 0x31, 0x69, 0x2e, 0x62, 0x66,
      0x82, 0xa9, 0xad, 0xfb, 0xb5, 0xd6, 0x94, 0xc9,
      0xb3, 0xa1, 0xfd, 0x24, 0xd9, 0x63, 0x77, 0x29,
      0x77, 0xe9, 0x1c, 0x71, 0x21, 0x8b, 0xf6, 0x4f,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__get_type_hash(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xac, 0x04, 0x18, 0x44, 0x29, 0x41, 0xbb, 0x65,
      0xe1, 0x8d, 0xb8, 0x63, 0x16, 0x80, 0xfb, 0xfd,
      0xab, 0x90, 0xce, 0xbf, 0x86, 0xc1, 0x08, 0x80,
      0x73, 0xf3, 0xa8, 0x54, 0xb0, 0xdb, 0x1e, 0xe6,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x58, 0x94, 0xc2, 0x14, 0xe0, 0xff, 0xad, 0x21,
      0xec, 0x7a, 0xf3, 0xb4, 0x5a, 0x01, 0x9b, 0xb8,
      0x31, 0x83, 0x0e, 0x97, 0xcc, 0xfc, 0xa4, 0x20,
      0xf5, 0x36, 0xae, 0x92, 0x1a, 0x22, 0xc1, 0x0e,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x2c, 0xb2, 0xc8, 0x9c, 0x18, 0xba, 0xee, 0x7f,
      0xe0, 0x5a, 0xfa, 0xac, 0xcd, 0xed, 0x7e, 0xc9,
      0xe7, 0xf1, 0x7d, 0x91, 0x38, 0xcc, 0xdc, 0xf9,
      0x0a, 0x5b, 0xc7, 0x2a, 0x78, 0xf4, 0xa3, 0x89,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x4e, 0x5b, 0x1f, 0x47, 0x39, 0x30, 0xd2, 0x23,
      0xf7, 0xab, 0x3a, 0x7a, 0xa1, 0x66, 0x13, 0xb3,
      0x20, 0x34, 0x49, 0x7f, 0xe8, 0xa0, 0x5b, 0xec,
      0x6b, 0x0b, 0x20, 0x1b, 0xc9, 0x69, 0xf5, 0xf7,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__get_type_hash(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x52, 0x33, 0x0c, 0x08, 0x2c, 0x4d, 0xdb, 0xd8,
      0xb8, 0x11, 0x92, 0x64, 0xe1, 0x84, 0xb5, 0xbf,
      0x3d, 0xdf, 0xb5, 0x44, 0x3c, 0xec, 0x53, 0x19,
      0x1c, 0xcb, 0xd1, 0x23, 0xd8, 0xba, 0xa0, 0xd5,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xef, 0xdc, 0x16, 0xe7, 0x57, 0xe5, 0x7a, 0x0b,
      0x31, 0x62, 0xc6, 0x89, 0x89, 0x94, 0xcf, 0x98,
      0x41, 0x63, 0x38, 0x51, 0x85, 0x27, 0x19, 0xd6,
      0xb2, 0xf7, 0xf8, 0xc6, 0xd2, 0x97, 0xf6, 0x97,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xef, 0x02, 0x4a, 0xb5, 0xdc, 0xf7, 0xab, 0xe7,
      0x15, 0x84, 0x73, 0x9c, 0x52, 0xe8, 0x9d, 0x8f,
      0x17, 0x74, 0x71, 0x15, 0xfa, 0xf2, 0x80, 0x7c,
      0x3a, 0x8c, 0x2c, 0x33, 0x7f, 0x2a, 0xfe, 0x8e,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x65, 0xb0, 0x7c, 0x8d, 0xeb, 0x32, 0x24, 0x4b,
      0xa6, 0x24, 0xff, 0x06, 0x19, 0x64, 0xeb, 0xb9,
      0x48, 0x40, 0x3e, 0x32, 0xd6, 0x38, 0x00, 0xfe,
      0x5a, 0xdf, 0x00, 0xd9, 0x27, 0xfa, 0xd4, 0x39,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xfe, 0x13, 0x3a, 0xda, 0xdc, 0x2e, 0x74, 0xdc,
      0x78, 0xd3, 0x99, 0xf8, 0xc8, 0x58, 0x80, 0x1c,
      0xe9, 0x42, 0xc5, 0x4d, 0x9d, 0x09, 0xfb, 0xaa,
      0x6f, 0x7c, 0x77, 0xc1, 0x9b, 0x0a, 0xb1, 0x18,
    }};
  return &hash;
}

#include <assert.h>
#include <string.h>

// Include directives for referenced types
#include "geometry_msgs/msg/detail/pose__functions.h"
#include "service_msgs/msg/detail/service_event_info__functions.h"
#include "unique_identifier_msgs/msg/detail/uuid__functions.h"
#include "control_msgs/msg/detail/motion_primitive__functions.h"
#include "std_msgs/msg/detail/header__functions.h"
#include "geometry_msgs/msg/detail/quaternion__functions.h"
#include "builtin_interfaces/msg/detail/time__functions.h"
#include "geometry_msgs/msg/detail/pose_stamped__functions.h"
#include "control_msgs/msg/detail/motion_primitive_sequence__functions.h"
#include "geometry_msgs/msg/detail/point__functions.h"
#include "control_msgs/msg/detail/motion_argument__functions.h"

// Hashes for external referenced types
#ifndef NDEBUG
static const rosidl_type_hash_t builtin_interfaces__msg__Time__EXPECTED_HASH = {1, {
    0xb1, 0x06, 0x23, 0x5e, 0x25, 0xa4, 0xc5, 0xed,
    0x35, 0x09, 0x8a, 0xa0, 0xa6, 0x1a, 0x3e, 0xe9,
    0xc9, 0xb1, 0x8d, 0x19, 0x7f, 0x39, 0x8b, 0x0e,
    0x42, 0x06, 0xce, 0xa9, 0xac, 0xf9, 0xc1, 0x97,
  }};
static const rosidl_type_hash_t control_msgs__msg__MotionArgument__EXPECTED_HASH = {1, {
    0x68, 0x7b, 0x5e, 0xa4, 0x3a, 0xbb, 0xba, 0x3a,
    0xb7, 0xc3, 0xa2, 0x2d, 0x39, 0xc2, 0x5d, 0x1e,
    0xca, 0x0b, 0x71, 0x28, 0x7a, 0xa0, 0x97, 0xd9,
    0x3b, 0xc9, 0xd9, 0x4d, 0x1d, 0x90, 0x0b, 0x7b,
  }};
static const rosidl_type_hash_t control_msgs__msg__MotionPrimitive__EXPECTED_HASH = {1, {
    0x04, 0xbc, 0x62, 0xc5, 0x54, 0x72, 0x20, 0x6d,
    0x3b, 0x97, 0x19, 0x20, 0x1a, 0x9f, 0x81, 0xe0,
    0x84, 0xa9, 0x3d, 0x2a, 0x88, 0x50, 0x56, 0xfc,
    0x7c, 0x1d, 0x94, 0xdb, 0x5f, 0xdb, 0x5c, 0xa5,
  }};
static const rosidl_type_hash_t control_msgs__msg__MotionPrimitiveSequence__EXPECTED_HASH = {1, {
    0x91, 0xc3, 0x34, 0x02, 0xc4, 0x7d, 0xf6, 0x28,
    0x86, 0x15, 0x22, 0x55, 0xa6, 0x88, 0x46, 0xf6,
    0x16, 0x99, 0xbb, 0x2a, 0x36, 0xd0, 0x61, 0xb3,
    0xbd, 0x1b, 0x38, 0x98, 0xe0, 0xf5, 0x15, 0x23,
  }};
static const rosidl_type_hash_t geometry_msgs__msg__Point__EXPECTED_HASH = {1, {
    0x69, 0x63, 0x08, 0x48, 0x42, 0xa9, 0xb0, 0x44,
    0x94, 0xd6, 0xb2, 0x94, 0x1d, 0x11, 0x44, 0x47,
    0x08, 0xd8, 0x92, 0xda, 0x2f, 0x4b, 0x09, 0x84,
    0x3b, 0x9c, 0x43, 0xf4, 0x2a, 0x7f, 0x68, 0x81,
  }};
static const rosidl_type_hash_t geometry_msgs__msg__Pose__EXPECTED_HASH = {1, {
    0xd5, 0x01, 0x95, 0x4e, 0x94, 0x76, 0xce, 0xa2,
    0x99, 0x69, 0x84, 0xe8, 0x12, 0x05, 0x4b, 0x68,
    0x02, 0x6a, 0xe0, 0xbf, 0xae, 0x78, 0x9d, 0x9a,
    0x10, 0xb2, 0x3d, 0xaf, 0x35, 0xcc, 0x90, 0xfa,
  }};
static const rosidl_type_hash_t geometry_msgs__msg__PoseStamped__EXPECTED_HASH = {1, {
    0x10, 0xf3, 0x78, 0x6d, 0x7d, 0x40, 0xfd, 0x2b,
    0x54, 0x36, 0x78, 0x35, 0x61, 0x4b, 0xff, 0x85,
    0xd4, 0xad, 0x3b, 0x5d, 0xab, 0x62, 0xbf, 0x8b,
    0xca, 0x0c, 0xc2, 0x32, 0xd7, 0x3b, 0x4c, 0xd8,
  }};
static const rosidl_type_hash_t geometry_msgs__msg__Quaternion__EXPECTED_HASH = {1, {
    0x8a, 0x76, 0x5f, 0x66, 0x77, 0x8c, 0x8f, 0xf7,
    0xc8, 0xab, 0x94, 0xaf, 0xcc, 0x59, 0x0a, 0x2e,
    0xd5, 0x32, 0x5a, 0x1d, 0x9a, 0x07, 0x6f, 0xff,
    0xf3, 0x8f, 0xbc, 0xe3, 0x6f, 0x45, 0x86, 0x84,
  }};
static const rosidl_type_hash_t service_msgs__msg__ServiceEventInfo__EXPECTED_HASH = {1, {
    0x41, 0xbc, 0xbb, 0xe0, 0x7a, 0x75, 0xc9, 0xb5,
    0x2b, 0xc9, 0x6b, 0xfd, 0x5c, 0x24, 0xd7, 0xf0,
    0xfc, 0x0a, 0x08, 0xc0, 0xcb, 0x79, 0x21, 0xb3,
    0x37, 0x3c, 0x57, 0x32, 0x34, 0x5a, 0x6f, 0x45,
  }};
static const rosidl_type_hash_t std_msgs__msg__Header__EXPECTED_HASH = {1, {
    0xf4, 0x9f, 0xb3, 0xae, 0x2c, 0xf0, 0x70, 0xf7,
    0x93, 0x64, 0x5f, 0xf7, 0x49, 0x68, 0x3a, 0xc6,
    0xb0, 0x62, 0x03, 0xe4, 0x1c, 0x89, 0x1e, 0x17,
    0x70, 0x1b, 0x1c, 0xb5, 0x97, 0xce, 0x6a, 0x01,
  }};
static const rosidl_type_hash_t unique_identifier_msgs__msg__UUID__EXPECTED_HASH = {1, {
    0x1b, 0x8e, 0x8a, 0xca, 0x95, 0x8c, 0xbe, 0xa2,
    0x8f, 0xe6, 0xef, 0x60, 0xbf, 0x6c, 0x19, 0xb6,
    0x83, 0xc9, 0x7a, 0x9e, 0xf6, 0x0b, 0xb3, 0x47,
    0x52, 0x06, 0x7d, 0x0f, 0x2f, 0x7a, 0xb4, 0x37,
  }};
#endif

static char control_msgs__action__ExecuteMotionPrimitiveSequence__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence";
static char builtin_interfaces__msg__Time__TYPE_NAME[] = "builtin_interfaces/msg/Time";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_Feedback";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_FeedbackMessage";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_GetResult";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_GetResult_Event";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_GetResult_Request";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_GetResult_Response";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_Goal";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_Result";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_SendGoal";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_SendGoal_Event";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_SendGoal_Request";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__TYPE_NAME[] = "control_msgs/action/ExecuteMotionPrimitiveSequence_SendGoal_Response";
static char control_msgs__msg__MotionArgument__TYPE_NAME[] = "control_msgs/msg/MotionArgument";
static char control_msgs__msg__MotionPrimitive__TYPE_NAME[] = "control_msgs/msg/MotionPrimitive";
static char control_msgs__msg__MotionPrimitiveSequence__TYPE_NAME[] = "control_msgs/msg/MotionPrimitiveSequence";
static char geometry_msgs__msg__Point__TYPE_NAME[] = "geometry_msgs/msg/Point";
static char geometry_msgs__msg__Pose__TYPE_NAME[] = "geometry_msgs/msg/Pose";
static char geometry_msgs__msg__PoseStamped__TYPE_NAME[] = "geometry_msgs/msg/PoseStamped";
static char geometry_msgs__msg__Quaternion__TYPE_NAME[] = "geometry_msgs/msg/Quaternion";
static char service_msgs__msg__ServiceEventInfo__TYPE_NAME[] = "service_msgs/msg/ServiceEventInfo";
static char std_msgs__msg__Header__TYPE_NAME[] = "std_msgs/msg/Header";
static char unique_identifier_msgs__msg__UUID__TYPE_NAME[] = "unique_identifier_msgs/msg/UUID";

// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__goal[] = "goal";
static char control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__result[] = "result";
static char control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__feedback[] = "feedback";
static char control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__send_goal_service[] = "send_goal_service";
static char control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__get_result_service[] = "get_result_service";
static char control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__feedback_message[] = "feedback_message";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__goal, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME, 55, 55},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__result, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME, 57, 57},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__feedback, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__TYPE_NAME, 59, 59},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__send_goal_service, 17, 17},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__TYPE_NAME, 59, 59},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__get_result_service, 18, 18},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__TYPE_NAME, 60, 60},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence__FIELD_NAME__feedback_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__TYPE_NAME, 66, 66},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__TYPE_NAME, 59, 59},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__TYPE_NAME, 66, 66},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__TYPE_NAME, 60, 60},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__TYPE_NAME, 66, 66},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__TYPE_NAME, 68, 68},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__TYPE_NAME, 69, 69},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME, 55, 55},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__TYPE_NAME, 59, 59},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__TYPE_NAME, 65, 65},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__TYPE_NAME, 67, 67},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__TYPE_NAME, 68, 68},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionArgument__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitive__TYPE_NAME, 32, 32},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitiveSequence__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Point__TYPE_NAME, 23, 23},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Pose__TYPE_NAME, 22, 22},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__PoseStamped__TYPE_NAME, 29, 29},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence__get_type_description(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence__TYPE_NAME, 50, 50},
      {control_msgs__action__ExecuteMotionPrimitiveSequence__FIELDS, 6, 6},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence__REFERENCED_TYPE_DESCRIPTIONS, 23, 23},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[5].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[6].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[7].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[8].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[9].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[10].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[11].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[12].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionArgument__EXPECTED_HASH, control_msgs__msg__MotionArgument__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[13].fields = control_msgs__msg__MotionArgument__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitive__EXPECTED_HASH, control_msgs__msg__MotionPrimitive__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[14].fields = control_msgs__msg__MotionPrimitive__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitiveSequence__EXPECTED_HASH, control_msgs__msg__MotionPrimitiveSequence__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[15].fields = control_msgs__msg__MotionPrimitiveSequence__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Point__EXPECTED_HASH, geometry_msgs__msg__Point__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[16].fields = geometry_msgs__msg__Point__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Pose__EXPECTED_HASH, geometry_msgs__msg__Pose__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[17].fields = geometry_msgs__msg__Pose__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__PoseStamped__EXPECTED_HASH, geometry_msgs__msg__PoseStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[18].fields = geometry_msgs__msg__PoseStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[19].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[20].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[21].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[22].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__FIELD_NAME__trajectory[] = "trajectory";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__FIELD_NAME__trajectory, 10, 10},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__msg__MotionPrimitiveSequence__TYPE_NAME, 40, 40},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionArgument__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitive__TYPE_NAME, 32, 32},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitiveSequence__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Point__TYPE_NAME, 23, 23},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Pose__TYPE_NAME, 22, 22},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__PoseStamped__TYPE_NAME, 29, 29},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME, 55, 55},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__FIELDS, 1, 1},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__REFERENCED_TYPE_DESCRIPTIONS, 9, 9},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionArgument__EXPECTED_HASH, control_msgs__msg__MotionArgument__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = control_msgs__msg__MotionArgument__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitive__EXPECTED_HASH, control_msgs__msg__MotionPrimitive__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = control_msgs__msg__MotionPrimitive__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitiveSequence__EXPECTED_HASH, control_msgs__msg__MotionPrimitiveSequence__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = control_msgs__msg__MotionPrimitiveSequence__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Point__EXPECTED_HASH, geometry_msgs__msg__Point__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = geometry_msgs__msg__Point__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Pose__EXPECTED_HASH, geometry_msgs__msg__Pose__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = geometry_msgs__msg__Pose__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__PoseStamped__EXPECTED_HASH, geometry_msgs__msg__PoseStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = geometry_msgs__msg__PoseStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[7].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[8].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_Result__FIELD_NAME__error_code[] = "error_code";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_Result__FIELD_NAME__error_string[] = "error_string";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_Result__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__FIELD_NAME__error_code, 10, 10},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_INT32,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__FIELD_NAME__error_string, 12, 12},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_STRING,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME, 57, 57},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__FIELDS, 2, 2},
    },
    {NULL, 0, 0},
  };
  if (!constructed) {
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__FIELD_NAME__current_primitive_index[] = "current_primitive_index";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__FIELD_NAME__current_primitive_index, 23, 23},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_UINT8,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__TYPE_NAME, 59, 59},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__FIELDS, 1, 1},
    },
    {NULL, 0, 0},
  };
  if (!constructed) {
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__FIELD_NAME__request_message[] = "request_message";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__FIELD_NAME__response_message[] = "response_message";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__FIELD_NAME__event_message[] = "event_message";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__FIELD_NAME__request_message, 15, 15},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__TYPE_NAME, 67, 67},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__FIELD_NAME__response_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__TYPE_NAME, 68, 68},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__FIELD_NAME__event_message, 13, 13},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__TYPE_NAME, 65, 65},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME, 55, 55},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__TYPE_NAME, 65, 65},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__TYPE_NAME, 67, 67},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__TYPE_NAME, 68, 68},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionArgument__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitive__TYPE_NAME, 32, 32},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitiveSequence__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Point__TYPE_NAME, 23, 23},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Pose__TYPE_NAME, 22, 22},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__PoseStamped__TYPE_NAME, 29, 29},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__get_type_description(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__TYPE_NAME, 59, 59},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__FIELDS, 3, 3},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__REFERENCED_TYPE_DESCRIPTIONS, 15, 15},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionArgument__EXPECTED_HASH, control_msgs__msg__MotionArgument__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = control_msgs__msg__MotionArgument__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitive__EXPECTED_HASH, control_msgs__msg__MotionPrimitive__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = control_msgs__msg__MotionPrimitive__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitiveSequence__EXPECTED_HASH, control_msgs__msg__MotionPrimitiveSequence__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[7].fields = control_msgs__msg__MotionPrimitiveSequence__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Point__EXPECTED_HASH, geometry_msgs__msg__Point__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[8].fields = geometry_msgs__msg__Point__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Pose__EXPECTED_HASH, geometry_msgs__msg__Pose__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[9].fields = geometry_msgs__msg__Pose__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__PoseStamped__EXPECTED_HASH, geometry_msgs__msg__PoseStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[10].fields = geometry_msgs__msg__PoseStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[11].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[12].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[13].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[14].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__FIELD_NAME__goal_id[] = "goal_id";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__FIELD_NAME__goal[] = "goal";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__FIELD_NAME__goal, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME, 55, 55},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME, 55, 55},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionArgument__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitive__TYPE_NAME, 32, 32},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitiveSequence__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Point__TYPE_NAME, 23, 23},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Pose__TYPE_NAME, 22, 22},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__PoseStamped__TYPE_NAME, 29, 29},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__TYPE_NAME, 67, 67},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__FIELDS, 2, 2},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__REFERENCED_TYPE_DESCRIPTIONS, 11, 11},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionArgument__EXPECTED_HASH, control_msgs__msg__MotionArgument__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = control_msgs__msg__MotionArgument__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitive__EXPECTED_HASH, control_msgs__msg__MotionPrimitive__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = control_msgs__msg__MotionPrimitive__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitiveSequence__EXPECTED_HASH, control_msgs__msg__MotionPrimitiveSequence__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = control_msgs__msg__MotionPrimitiveSequence__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Point__EXPECTED_HASH, geometry_msgs__msg__Point__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = geometry_msgs__msg__Point__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Pose__EXPECTED_HASH, geometry_msgs__msg__Pose__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = geometry_msgs__msg__Pose__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__PoseStamped__EXPECTED_HASH, geometry_msgs__msg__PoseStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[7].fields = geometry_msgs__msg__PoseStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[8].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[9].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[10].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__FIELD_NAME__accepted[] = "accepted";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__FIELD_NAME__stamp[] = "stamp";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__FIELD_NAME__accepted, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_BOOLEAN,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__FIELD_NAME__stamp, 5, 5},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__TYPE_NAME, 68, 68},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__FIELDS, 2, 2},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__FIELD_NAME__info[] = "info";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__FIELD_NAME__request[] = "request";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__FIELD_NAME__response[] = "response";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__FIELD_NAME__info, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__FIELD_NAME__request, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__TYPE_NAME, 67, 67},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__FIELD_NAME__response, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__TYPE_NAME, 68, 68},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME, 55, 55},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__TYPE_NAME, 67, 67},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__TYPE_NAME, 68, 68},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionArgument__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitive__TYPE_NAME, 32, 32},
    {NULL, 0, 0},
  },
  {
    {control_msgs__msg__MotionPrimitiveSequence__TYPE_NAME, 40, 40},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Point__TYPE_NAME, 23, 23},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Pose__TYPE_NAME, 22, 22},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__PoseStamped__TYPE_NAME, 29, 29},
    {NULL, 0, 0},
  },
  {
    {geometry_msgs__msg__Quaternion__TYPE_NAME, 28, 28},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__TYPE_NAME, 65, 65},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__FIELDS, 3, 3},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__REFERENCED_TYPE_DESCRIPTIONS, 14, 14},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionArgument__EXPECTED_HASH, control_msgs__msg__MotionArgument__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = control_msgs__msg__MotionArgument__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitive__EXPECTED_HASH, control_msgs__msg__MotionPrimitive__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = control_msgs__msg__MotionPrimitive__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&control_msgs__msg__MotionPrimitiveSequence__EXPECTED_HASH, control_msgs__msg__MotionPrimitiveSequence__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = control_msgs__msg__MotionPrimitiveSequence__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Point__EXPECTED_HASH, geometry_msgs__msg__Point__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[7].fields = geometry_msgs__msg__Point__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Pose__EXPECTED_HASH, geometry_msgs__msg__Pose__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[8].fields = geometry_msgs__msg__Pose__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__PoseStamped__EXPECTED_HASH, geometry_msgs__msg__PoseStamped__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[9].fields = geometry_msgs__msg__PoseStamped__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&geometry_msgs__msg__Quaternion__EXPECTED_HASH, geometry_msgs__msg__Quaternion__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[10].fields = geometry_msgs__msg__Quaternion__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[11].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[12].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[13].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__FIELD_NAME__request_message[] = "request_message";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__FIELD_NAME__response_message[] = "response_message";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__FIELD_NAME__event_message[] = "event_message";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__FIELD_NAME__request_message, 15, 15},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__TYPE_NAME, 68, 68},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__FIELD_NAME__response_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__TYPE_NAME, 69, 69},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__FIELD_NAME__event_message, 13, 13},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__TYPE_NAME, 66, 66},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__TYPE_NAME, 66, 66},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__TYPE_NAME, 68, 68},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__TYPE_NAME, 69, 69},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__get_type_description(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__TYPE_NAME, 60, 60},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__FIELDS, 3, 3},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__REFERENCED_TYPE_DESCRIPTIONS, 7, 7},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__FIELD_NAME__goal_id[] = "goal_id";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__TYPE_NAME, 68, 68},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__FIELDS, 1, 1},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__FIELD_NAME__status[] = "status";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__FIELD_NAME__result[] = "result";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__FIELD_NAME__status, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_INT8,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__FIELD_NAME__result, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME, 57, 57},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__TYPE_NAME, 69, 69},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__FIELDS, 2, 2},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    description.referenced_type_descriptions.data[0].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__FIELD_NAME__info[] = "info";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__FIELD_NAME__request[] = "request";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__FIELD_NAME__response[] = "response";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__FIELD_NAME__info, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__FIELD_NAME__request, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__TYPE_NAME, 68, 68},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__FIELD_NAME__response, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__TYPE_NAME, 69, 69},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__TYPE_NAME, 68, 68},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__TYPE_NAME, 69, 69},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__TYPE_NAME, 66, 66},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__FIELDS, 3, 3},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__REFERENCED_TYPE_DESCRIPTIONS, 6, 6},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__FIELD_NAME__goal_id[] = "goal_id";
static char control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__FIELD_NAME__feedback[] = "feedback";

static rosidl_runtime_c__type_description__Field control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__FIELDS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__FIELD_NAME__feedback, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__TYPE_NAME, 59, 59},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__TYPE_NAME, 59, 59},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__TYPE_NAME, 66, 66},
      {control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__FIELDS, 2, 2},
    },
    {control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__REFERENCED_TYPE_DESCRIPTIONS, 2, 2},
  };
  if (!constructed) {
    description.referenced_type_descriptions.data[0].fields = control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}

static char toplevel_type_raw_source[] =
  "# A list of MotionPrimitive messages that are executed in sequence. They don't have to be of the\n"
  "# same type, as long as the robot supports executing them one after another.\n"
  "MotionPrimitiveSequence trajectory\n"
  "---\n"
  "int32 SUCCESSFUL = 0\n"
  "int32 INVALID_GOAL = -1\n"
  "int32 OLD_HEADER_TIMESTAMP = -3\n"
  "\n"
  "int32 error_code\n"
  "string error_string\n"
  "---\n"
  "# Index of the currently executed motion primitive in the sequence.\n"
  "uint8 current_primitive_index";

static char action_encoding[] = "action";
static char implicit_encoding[] = "implicit";

// Define all individual source functions

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence__get_individual_type_description_source(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence__TYPE_NAME, 50, 50},
    {action_encoding, 6, 6},
    {toplevel_type_raw_source, 430, 430},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__TYPE_NAME, 55, 55},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Result__TYPE_NAME, 57, 57},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__TYPE_NAME, 59, 59},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__get_individual_type_description_source(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__TYPE_NAME, 59, 59},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__TYPE_NAME, 67, 67},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__TYPE_NAME, 68, 68},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__TYPE_NAME, 65, 65},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__get_individual_type_description_source(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__TYPE_NAME, 60, 60},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__TYPE_NAME, 68, 68},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__TYPE_NAME, 69, 69},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__TYPE_NAME, 66, 66},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__TYPE_NAME, 66, 66},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence__get_type_description_sources(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[24];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 24, 24};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_individual_type_description_source(NULL);
    sources[6] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_individual_type_description_source(NULL);
    sources[7] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_individual_type_description_source(NULL);
    sources[8] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_individual_type_description_source(NULL);
    sources[9] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_individual_type_description_source(NULL);
    sources[10] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__get_individual_type_description_source(NULL);
    sources[11] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_individual_type_description_source(NULL);
    sources[12] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[13] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[14] = *control_msgs__msg__MotionArgument__get_individual_type_description_source(NULL);
    sources[15] = *control_msgs__msg__MotionPrimitive__get_individual_type_description_source(NULL);
    sources[16] = *control_msgs__msg__MotionPrimitiveSequence__get_individual_type_description_source(NULL);
    sources[17] = *geometry_msgs__msg__Point__get_individual_type_description_source(NULL);
    sources[18] = *geometry_msgs__msg__Pose__get_individual_type_description_source(NULL);
    sources[19] = *geometry_msgs__msg__PoseStamped__get_individual_type_description_source(NULL);
    sources[20] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[21] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[22] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[23] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[10];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 10, 10};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__msg__MotionArgument__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__msg__MotionPrimitive__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__msg__MotionPrimitiveSequence__get_individual_type_description_source(NULL);
    sources[5] = *geometry_msgs__msg__Point__get_individual_type_description_source(NULL);
    sources[6] = *geometry_msgs__msg__Pose__get_individual_type_description_source(NULL);
    sources[7] = *geometry_msgs__msg__PoseStamped__get_individual_type_description_source(NULL);
    sources[8] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[9] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[1];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 1, 1};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_individual_type_description_source(NULL),
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[1];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 1, 1};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_individual_type_description_source(NULL),
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__get_type_description_sources(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[16];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 16, 16};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[6] = *control_msgs__msg__MotionArgument__get_individual_type_description_source(NULL);
    sources[7] = *control_msgs__msg__MotionPrimitive__get_individual_type_description_source(NULL);
    sources[8] = *control_msgs__msg__MotionPrimitiveSequence__get_individual_type_description_source(NULL);
    sources[9] = *geometry_msgs__msg__Point__get_individual_type_description_source(NULL);
    sources[10] = *geometry_msgs__msg__Pose__get_individual_type_description_source(NULL);
    sources[11] = *geometry_msgs__msg__PoseStamped__get_individual_type_description_source(NULL);
    sources[12] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[13] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[14] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[15] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[12];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 12, 12};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__msg__MotionArgument__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__msg__MotionPrimitive__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__msg__MotionPrimitiveSequence__get_individual_type_description_source(NULL);
    sources[6] = *geometry_msgs__msg__Point__get_individual_type_description_source(NULL);
    sources[7] = *geometry_msgs__msg__Pose__get_individual_type_description_source(NULL);
    sources[8] = *geometry_msgs__msg__PoseStamped__get_individual_type_description_source(NULL);
    sources[9] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[10] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[11] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[15];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 15, 15};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Event__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Goal__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__ExecuteMotionPrimitiveSequence_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__msg__MotionArgument__get_individual_type_description_source(NULL);
    sources[6] = *control_msgs__msg__MotionPrimitive__get_individual_type_description_source(NULL);
    sources[7] = *control_msgs__msg__MotionPrimitiveSequence__get_individual_type_description_source(NULL);
    sources[8] = *geometry_msgs__msg__Point__get_individual_type_description_source(NULL);
    sources[9] = *geometry_msgs__msg__Pose__get_individual_type_description_source(NULL);
    sources[10] = *geometry_msgs__msg__PoseStamped__get_individual_type_description_source(NULL);
    sources[11] = *geometry_msgs__msg__Quaternion__get_individual_type_description_source(NULL);
    sources[12] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[13] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[14] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__get_type_description_sources(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[8];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 8, 8};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_individual_type_description_source(NULL);
    sources[6] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[7] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_individual_type_description_source(NULL),
    sources[1] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_individual_type_description_source(NULL),
    sources[1] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[7];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 7, 7};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Event__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Request__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__ExecuteMotionPrimitiveSequence_GetResult_Response__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Result__get_individual_type_description_source(NULL);
    sources[5] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[6] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[3];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 3, 3};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__ExecuteMotionPrimitiveSequence_FeedbackMessage__get_individual_type_description_source(NULL),
    sources[1] = *control_msgs__action__ExecuteMotionPrimitiveSequence_Feedback__get_individual_type_description_source(NULL);
    sources[2] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}
