// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/InterfaceValue.msg
// generated code does not contain a copyright notice


module control_msgs {
  module msg {
    @verbatim (language="comment", text=
      "List of resource interface names")
    struct InterfaceValue {
      sequence<string> interface_names;

      @verbatim (language="comment", text=
        "Values corresponding to the list of interfaces in `interface_names`, [1.0, 0.0] for example")
      sequence<double> values;
    };
  };
};
