// generated from rosidl_generator_c/resource/idl.h.em
// with input from control_msgs:msg/InterfaceValue.idl
// generated code does not contain a copyright notice

#ifndef CONTROL_MSGS__MSG__INTERFACE_VALUE_H_
#define CONTROL_MSGS__MSG__INTERFACE_VALUE_H_

#include "control_msgs/msg/detail/interface_value__struct.h"
#include "control_msgs/msg/detail/interface_value__functions.h"
#include "control_msgs/msg/detail/interface_value__type_support.h"

#endif  // CONTROL_MSGS__MSG__INTERFACE_VALUE_H_
