// generated from rosidl_generator_c/resource/idl.h.em
// with input from control_msgs:action/ParallelGripperCommand.idl
// generated code does not contain a copyright notice

#ifndef CONTROL_MSGS__ACTION__PARALLEL_GRIPPER_COMMAND_H_
#define CONTROL_MSGS__ACTION__PARALLEL_GRIPPER_COMMAND_H_

#include "control_msgs/action/detail/parallel_gripper_command__struct.h"
#include "control_msgs/action/detail/parallel_gripper_command__functions.h"
#include "control_msgs/action/detail/parallel_gripper_command__type_support.h"

#endif  // CONTROL_MSGS__ACTION__PARALLEL_GRIPPER_COMMAND_H_
