// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/BatteryStateArray.msg
// generated code does not contain a copyright notice

#include "sensor_msgs/msg/BatteryState.idl"

module control_msgs {
  module msg {
    @verbatim (language="comment", text=
      "This message publishes values for multiple batteries at once.")
    struct BatteryStateArray {
      sequence<sensor_msgs::msg::BatteryState> battery_states;
    };
  };
};
