// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/VDA5050SafetyState.msg
// generated code does not contain a copyright notice


module control_msgs {
  module msg {
    module VDA5050SafetyState_Constants {
      @verbatim (language="comment", text=
        "Enums for eStop")
      const string AUTO_ACK = "autoAck";
      const string MANUAL = "manual";
      const string REMOTE = "remote";
      const string NONE = "none";
    };
    struct VDA5050SafetyState {
      @verbatim (language="comment", text=
        "Enum {autoAck, manual, remote, none} Acknowledge-Type of eStop:" "\n"
        "autoAck: autoacknowledgeable e-stop is activated e.g. by bumper or protective field" "\n"
        "manual: e-stop has to be acknowledged manually at the vehicle" "\n"
        "remote: facility estop has to be acknowledged remotely" "\n"
        "none: no e-stop activated")
      string e_stop;

      @verbatim (language="comment", text=
        "Protective field violation. True: field is violated False: field is not violated")
      boolean field_violation;
    };
  };
};
