// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/JointJog.msg
// generated code does not contain a copyright notice

#include "std_msgs/msg/Header.idl"

module control_msgs {
  module msg {
    @verbatim (language="comment", text=
      "Used in time-stamping the message.")
    struct JointJog {
      std_msgs::msg::Header header;

      @verbatim (language="comment", text=
        "Name list of the joints. You don't need to specify all joints of the" "\n"
        "robot. Joint names are case-sensitive.")
      sequence<string> joint_names;

      @verbatim (language="comment", text=
        "A position command to the joints listed in joint_names." "\n"
        "The order must be identical." "\n"
        "Units are meters or radians." "\n"
        "If displacements and velocities are filled, a profiled motion is requested." "\n"
        "or position_deltas")
      sequence<double> displacements;

      @verbatim (language="comment", text=
        "A velocity command to the joints listed in joint_names." "\n"
        "The order must be identical." "\n"
        "Units are m/s or rad/s." "\n"
        "If displacements and velocities are filled, a profiled motion is requested.")
      sequence<double> velocities;

      double duration;
    };
  };
};
