// generated from rosidl_generator_cpp/resource/idl.hpp.em
// generated code does not contain a copyright notice

#ifndef CONTROL_MSGS__MSG__SINGLE_DOF_STATE_STAMPED_HPP_
#define CONTROL_MSGS__MSG__SINGLE_DOF_STATE_STAMPED_HPP_

#include "control_msgs/msg/detail/single_dof_state_stamped__struct.hpp"
#include "control_msgs/msg/detail/single_dof_state_stamped__builder.hpp"
#include "control_msgs/msg/detail/single_dof_state_stamped__traits.hpp"
#include "control_msgs/msg/detail/single_dof_state_stamped__type_support.hpp"

#endif  // CONTROL_MSGS__MSG__SINGLE_DOF_STATE_STAMPED_HPP_
