// generated from rosidl_adapter/resource/srv.idl.em
// with input from control_msgs/srv/SetOdometry.srv
// generated code does not contain a copyright notice


module control_msgs {
  module srv {
    struct SetOdometry_Request {
      double x;

      double y;

      double z;

      double roll;

      double pitch;

      double yaw;
    };
    struct SetOdometry_Response {
      boolean success;

      string message;
    };
  };
};
