// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/SpeedScalingFactor.msg
// generated code does not contain a copyright notice


module control_msgs {
  module msg {
    @verbatim (language="comment", text=
      "This message contains a scaling factor to scale trajectory execution. A factor of 1.0 means" "\n"
      "execution at normal speed, a factor of 0.0 means a full pause." "\n"
      "Negative values are not allowed (Which should be checked by any instance consuming this message).")
    struct SpeedScalingFactor {
      double factor;
    };
  };
};
