// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/MotionArgument.msg
// generated code does not contain a copyright notice


module control_msgs {
  module msg {
    @verbatim (language="comment", text=
      "Key Value pair to be used in MotionPrimitive messages")
    struct MotionArgument {
      string name;

      double value;
    };
  };
};
