// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/Keys.msg
// generated code does not contain a copyright notice

#include "std_msgs/msg/Header.idl"

module control_msgs {
  module msg {
    struct Keys {
      std_msgs::msg::Header header;

      @verbatim (language="comment", text=
        "List of names defining interfaces or joints or other string-based entities" "\n"
        "being published with Keys.msg")
      sequence<string> keys;
    };
  };
};
