// generated from rosidl_generator_c/resource/idl.h.em
// with input from control_msgs:msg/SteeringControllerStatus.idl
// generated code does not contain a copyright notice

#ifndef CONTROL_MSGS__MSG__STEERING_CONTROLLER_STATUS_H_
#define CONTROL_MSGS__MSG__STEERING_CONTROLLER_STATUS_H_

#include "control_msgs/msg/detail/steering_controller_status__struct.h"
#include "control_msgs/msg/detail/steering_controller_status__functions.h"
#include "control_msgs/msg/detail/steering_controller_status__type_support.h"

#endif  // CONTROL_MSGS__MSG__STEERING_CONTROLLER_STATUS_H_
