// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/DynamicJointState.msg
// generated code does not contain a copyright notice

#include "control_msgs/msg/InterfaceValue.idl"
#include "std_msgs/msg/Header.idl"

module control_msgs {
  module msg {
    struct DynamicJointState {
      std_msgs::msg::Header header;

      @verbatim (language="comment", text=
        "List of resource names, e.g. [\"arm_joint_1\", \"arm_joint_2\", \"gripper_joint\"]")
      sequence<string> joint_names;

      @verbatim (language="comment", text=
        "Key-value pairs representing interfaces and their corresponding values for each joint listed in `joint_names`")
      sequence<control_msgs::msg::InterfaceValue> interface_values;
    };
  };
};
