// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/SingleDOFStateStamped.msg
// generated code does not contain a copyright notice

#include "control_msgs/msg/SingleDOFState.idl"
#include "std_msgs/msg/Header.idl"

module control_msgs {
  module msg {
    @verbatim (language="comment", text=
      "This message presents current controller state of one degree of freedom.")
    struct SingleDOFStateStamped {
      @verbatim (language="comment", text=
        "Header timestamp should be update time of controller state")
      std_msgs::msg::Header header;

      control_msgs::msg::SingleDOFState dof_state;
    };
  };
};
