// generated from rosidl_generator_c/resource/idl__description.c.em
// with input from control_msgs:action/SingleJointPosition.idl
// generated code does not contain a copyright notice

#include "control_msgs/action/detail/single_joint_position__functions.h"

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition__get_type_hash(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x1b, 0x33, 0x0d, 0x11, 0x63, 0x8c, 0x0b, 0x1d,
      0x32, 0x28, 0xcc, 0x80, 0xb1, 0x12, 0x3e, 0x5b,
      0x3d, 0xb3, 0xd2, 0x45, 0x92, 0xe9, 0x54, 0x29,
      0x81, 0x2b, 0xf3, 0x00, 0x56, 0xe3, 0xdb, 0x7b,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_Goal__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xc4, 0x34, 0xf6, 0xbb, 0x75, 0x53, 0x96, 0xb6,
      0x03, 0x7c, 0x46, 0x76, 0x1f, 0x49, 0x25, 0x80,
      0xe7, 0x12, 0x1d, 0x17, 0x15, 0x7e, 0xad, 0x1d,
      0x58, 0xdf, 0xee, 0x17, 0x40, 0x01, 0xcf, 0x79,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_Result__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x4f, 0xa1, 0x0d, 0x55, 0x5d, 0x53, 0x9d, 0x00,
      0x37, 0x0b, 0x71, 0x14, 0xdb, 0x3c, 0x3d, 0xdd,
      0xb1, 0x82, 0x64, 0x7e, 0x72, 0x0c, 0x8c, 0x5f,
      0xaa, 0xf8, 0xe1, 0x84, 0x82, 0x2d, 0xb1, 0x4c,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_Feedback__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xb3, 0xeb, 0x28, 0x91, 0x32, 0x08, 0xb0, 0x1d,
      0x27, 0x13, 0xc9, 0x08, 0x06, 0x7a, 0x80, 0x3a,
      0x97, 0x5e, 0xf8, 0x1a, 0x8b, 0x94, 0x31, 0xfd,
      0x6b, 0x46, 0x39, 0xf2, 0xe9, 0x1f, 0xc1, 0xfc,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_SendGoal__get_type_hash(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xab, 0xcf, 0x6f, 0x8a, 0xcd, 0x18, 0x89, 0xa6,
      0x85, 0xcd, 0x6a, 0xc2, 0xe9, 0x48, 0x28, 0x4a,
      0x80, 0x12, 0xa8, 0x1d, 0x01, 0xe6, 0xaf, 0x0d,
      0x6a, 0x91, 0x8c, 0x52, 0xd7, 0x59, 0xca, 0x47,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_SendGoal_Request__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x5d, 0xdd, 0x69, 0x89, 0xbd, 0xf3, 0x38, 0x9d,
      0xf3, 0x44, 0x90, 0x4c, 0x69, 0xb0, 0x41, 0xd2,
      0xb7, 0xee, 0xc7, 0x6d, 0xfb, 0xb9, 0xfa, 0xd4,
      0xf6, 0x6c, 0xf3, 0x71, 0x4a, 0x3f, 0x08, 0x06,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_SendGoal_Response__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xbd, 0x3d, 0x63, 0xd7, 0x23, 0x61, 0xe5, 0x78,
      0xcc, 0x20, 0x35, 0xb5, 0xb2, 0x8d, 0xb7, 0x4b,
      0x10, 0xe8, 0x76, 0xdb, 0x60, 0x50, 0x60, 0x85,
      0x89, 0xfc, 0x8f, 0x0b, 0x52, 0x3f, 0x98, 0x39,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_SendGoal_Event__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xb5, 0x57, 0x2c, 0x9d, 0xd9, 0x29, 0x46, 0xf9,
      0x3c, 0x34, 0x1f, 0x99, 0x32, 0x79, 0x16, 0x68,
      0x90, 0x83, 0x11, 0x7d, 0x0b, 0x35, 0x12, 0x86,
      0x03, 0x97, 0x3a, 0x59, 0x0c, 0xe7, 0x31, 0x57,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_GetResult__get_type_hash(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xaf, 0xe9, 0x5c, 0x54, 0xe7, 0xc5, 0x9c, 0xdb,
      0x7e, 0x0d, 0x97, 0x8b, 0xfa, 0xfb, 0x90, 0x8e,
      0x3f, 0x15, 0x46, 0x97, 0x5d, 0x54, 0x09, 0x11,
      0xa1, 0x76, 0x80, 0x09, 0xd5, 0x77, 0x35, 0x1d,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_GetResult_Request__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0xd2, 0xb8, 0x70, 0x49, 0x68, 0x7e, 0xba, 0xd7,
      0x9b, 0xeb, 0xbd, 0x13, 0x0e, 0x69, 0x13, 0xb6,
      0x90, 0x06, 0x9f, 0xba, 0x19, 0xf1, 0x9b, 0x4b,
      0x47, 0x74, 0x75, 0x4f, 0x96, 0x9d, 0x15, 0x66,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_GetResult_Response__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x64, 0x75, 0xdf, 0x69, 0xe4, 0xfb, 0xff, 0x1a,
      0xa8, 0xdc, 0xd8, 0xd2, 0x82, 0x5e, 0x03, 0xf6,
      0xfa, 0xa3, 0xc6, 0x9f, 0x15, 0x8c, 0x8f, 0xe1,
      0xd0, 0x58, 0xeb, 0x50, 0x6d, 0x53, 0xee, 0x9e,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_GetResult_Event__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x1e, 0x88, 0x99, 0x81, 0x04, 0xec, 0x86, 0x15,
      0x63, 0x21, 0x94, 0x31, 0xe9, 0x75, 0x80, 0xd3,
      0xed, 0x24, 0xff, 0xc7, 0x92, 0xbe, 0xd4, 0xa9,
      0xfe, 0x26, 0x1a, 0x83, 0xe3, 0x95, 0x4c, 0x3a,
    }};
  return &hash;
}

ROSIDL_GENERATOR_C_PUBLIC_control_msgs
const rosidl_type_hash_t *
control_msgs__action__SingleJointPosition_FeedbackMessage__get_type_hash(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_type_hash_t hash = {1, {
      0x6d, 0xa1, 0x9e, 0xb4, 0x20, 0xdb, 0x90, 0x08,
      0x0a, 0x9b, 0xd9, 0xca, 0xc0, 0x04, 0x1c, 0x86,
      0x52, 0x54, 0xb8, 0xe4, 0x9c, 0xbe, 0x0d, 0x2b,
      0x54, 0xc7, 0x8e, 0x18, 0x14, 0xed, 0x49, 0x9b,
    }};
  return &hash;
}

#include <assert.h>
#include <string.h>

// Include directives for referenced types
#include "service_msgs/msg/detail/service_event_info__functions.h"
#include "unique_identifier_msgs/msg/detail/uuid__functions.h"
#include "builtin_interfaces/msg/detail/duration__functions.h"
#include "std_msgs/msg/detail/header__functions.h"
#include "builtin_interfaces/msg/detail/time__functions.h"

// Hashes for external referenced types
#ifndef NDEBUG
static const rosidl_type_hash_t builtin_interfaces__msg__Duration__EXPECTED_HASH = {1, {
    0xe8, 0xd0, 0x09, 0xf6, 0x59, 0x81, 0x6f, 0x75,
    0x8b, 0x75, 0x33, 0x4e, 0xe1, 0xa9, 0xca, 0x5b,
    0x5c, 0x0b, 0x85, 0x98, 0x43, 0x26, 0x1f, 0x14,
    0xc7, 0xf9, 0x37, 0x34, 0x95, 0x99, 0xd9, 0x3b,
  }};
static const rosidl_type_hash_t builtin_interfaces__msg__Time__EXPECTED_HASH = {1, {
    0xb1, 0x06, 0x23, 0x5e, 0x25, 0xa4, 0xc5, 0xed,
    0x35, 0x09, 0x8a, 0xa0, 0xa6, 0x1a, 0x3e, 0xe9,
    0xc9, 0xb1, 0x8d, 0x19, 0x7f, 0x39, 0x8b, 0x0e,
    0x42, 0x06, 0xce, 0xa9, 0xac, 0xf9, 0xc1, 0x97,
  }};
static const rosidl_type_hash_t service_msgs__msg__ServiceEventInfo__EXPECTED_HASH = {1, {
    0x41, 0xbc, 0xbb, 0xe0, 0x7a, 0x75, 0xc9, 0xb5,
    0x2b, 0xc9, 0x6b, 0xfd, 0x5c, 0x24, 0xd7, 0xf0,
    0xfc, 0x0a, 0x08, 0xc0, 0xcb, 0x79, 0x21, 0xb3,
    0x37, 0x3c, 0x57, 0x32, 0x34, 0x5a, 0x6f, 0x45,
  }};
static const rosidl_type_hash_t std_msgs__msg__Header__EXPECTED_HASH = {1, {
    0xf4, 0x9f, 0xb3, 0xae, 0x2c, 0xf0, 0x70, 0xf7,
    0x93, 0x64, 0x5f, 0xf7, 0x49, 0x68, 0x3a, 0xc6,
    0xb0, 0x62, 0x03, 0xe4, 0x1c, 0x89, 0x1e, 0x17,
    0x70, 0x1b, 0x1c, 0xb5, 0x97, 0xce, 0x6a, 0x01,
  }};
static const rosidl_type_hash_t unique_identifier_msgs__msg__UUID__EXPECTED_HASH = {1, {
    0x1b, 0x8e, 0x8a, 0xca, 0x95, 0x8c, 0xbe, 0xa2,
    0x8f, 0xe6, 0xef, 0x60, 0xbf, 0x6c, 0x19, 0xb6,
    0x83, 0xc9, 0x7a, 0x9e, 0xf6, 0x0b, 0xb3, 0x47,
    0x52, 0x06, 0x7d, 0x0f, 0x2f, 0x7a, 0xb4, 0x37,
  }};
#endif

static char control_msgs__action__SingleJointPosition__TYPE_NAME[] = "control_msgs/action/SingleJointPosition";
static char builtin_interfaces__msg__Duration__TYPE_NAME[] = "builtin_interfaces/msg/Duration";
static char builtin_interfaces__msg__Time__TYPE_NAME[] = "builtin_interfaces/msg/Time";
static char control_msgs__action__SingleJointPosition_Feedback__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_Feedback";
static char control_msgs__action__SingleJointPosition_FeedbackMessage__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_FeedbackMessage";
static char control_msgs__action__SingleJointPosition_GetResult__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_GetResult";
static char control_msgs__action__SingleJointPosition_GetResult_Event__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_GetResult_Event";
static char control_msgs__action__SingleJointPosition_GetResult_Request__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_GetResult_Request";
static char control_msgs__action__SingleJointPosition_GetResult_Response__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_GetResult_Response";
static char control_msgs__action__SingleJointPosition_Goal__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_Goal";
static char control_msgs__action__SingleJointPosition_Result__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_Result";
static char control_msgs__action__SingleJointPosition_SendGoal__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_SendGoal";
static char control_msgs__action__SingleJointPosition_SendGoal_Event__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_SendGoal_Event";
static char control_msgs__action__SingleJointPosition_SendGoal_Request__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_SendGoal_Request";
static char control_msgs__action__SingleJointPosition_SendGoal_Response__TYPE_NAME[] = "control_msgs/action/SingleJointPosition_SendGoal_Response";
static char service_msgs__msg__ServiceEventInfo__TYPE_NAME[] = "service_msgs/msg/ServiceEventInfo";
static char std_msgs__msg__Header__TYPE_NAME[] = "std_msgs/msg/Header";
static char unique_identifier_msgs__msg__UUID__TYPE_NAME[] = "unique_identifier_msgs/msg/UUID";

// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition__FIELD_NAME__goal[] = "goal";
static char control_msgs__action__SingleJointPosition__FIELD_NAME__result[] = "result";
static char control_msgs__action__SingleJointPosition__FIELD_NAME__feedback[] = "feedback";
static char control_msgs__action__SingleJointPosition__FIELD_NAME__send_goal_service[] = "send_goal_service";
static char control_msgs__action__SingleJointPosition__FIELD_NAME__get_result_service[] = "get_result_service";
static char control_msgs__action__SingleJointPosition__FIELD_NAME__feedback_message[] = "feedback_message";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition__FIELD_NAME__goal, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_Goal__TYPE_NAME, 44, 44},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition__FIELD_NAME__result, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_Result__TYPE_NAME, 46, 46},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition__FIELD_NAME__feedback, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_Feedback__TYPE_NAME, 48, 48},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition__FIELD_NAME__send_goal_service, 17, 17},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_SendGoal__TYPE_NAME, 48, 48},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition__FIELD_NAME__get_result_service, 18, 18},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_GetResult__TYPE_NAME, 49, 49},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition__FIELD_NAME__feedback_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_FeedbackMessage__TYPE_NAME, 55, 55},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Feedback__TYPE_NAME, 48, 48},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_FeedbackMessage__TYPE_NAME, 55, 55},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult__TYPE_NAME, 49, 49},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Event__TYPE_NAME, 55, 55},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Request__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Response__TYPE_NAME, 58, 58},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Goal__TYPE_NAME, 44, 44},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Result__TYPE_NAME, 46, 46},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal__TYPE_NAME, 48, 48},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Event__TYPE_NAME, 54, 54},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Request__TYPE_NAME, 56, 56},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Response__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition__get_type_description(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition__TYPE_NAME, 39, 39},
      {control_msgs__action__SingleJointPosition__FIELDS, 6, 6},
    },
    {control_msgs__action__SingleJointPosition__REFERENCED_TYPE_DESCRIPTIONS, 17, 17},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__SingleJointPosition_Feedback__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__SingleJointPosition_FeedbackMessage__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = control_msgs__action__SingleJointPosition_GetResult__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[5].fields = control_msgs__action__SingleJointPosition_GetResult_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[6].fields = control_msgs__action__SingleJointPosition_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[7].fields = control_msgs__action__SingleJointPosition_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[8].fields = control_msgs__action__SingleJointPosition_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[9].fields = control_msgs__action__SingleJointPosition_Result__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[10].fields = control_msgs__action__SingleJointPosition_SendGoal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[11].fields = control_msgs__action__SingleJointPosition_SendGoal_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[12].fields = control_msgs__action__SingleJointPosition_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[13].fields = control_msgs__action__SingleJointPosition_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[14].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[15].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[16].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_Goal__FIELD_NAME__position[] = "position";
static char control_msgs__action__SingleJointPosition_Goal__FIELD_NAME__min_duration[] = "min_duration";
static char control_msgs__action__SingleJointPosition_Goal__FIELD_NAME__max_velocity[] = "max_velocity";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_Goal__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_Goal__FIELD_NAME__position, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_DOUBLE,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Goal__FIELD_NAME__min_duration, 12, 12},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Goal__FIELD_NAME__max_velocity, 12, 12},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_DOUBLE,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_Goal__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_Goal__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_Goal__TYPE_NAME, 44, 44},
      {control_msgs__action__SingleJointPosition_Goal__FIELDS, 3, 3},
    },
    {control_msgs__action__SingleJointPosition_Goal__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_Result__FIELD_NAME__structure_needs_at_least_one_member[] = "structure_needs_at_least_one_member";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_Result__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_Result__FIELD_NAME__structure_needs_at_least_one_member, 35, 35},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_UINT8,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_Result__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_Result__TYPE_NAME, 46, 46},
      {control_msgs__action__SingleJointPosition_Result__FIELDS, 1, 1},
    },
    {NULL, 0, 0},
  };
  if (!constructed) {
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_Feedback__FIELD_NAME__header[] = "header";
static char control_msgs__action__SingleJointPosition_Feedback__FIELD_NAME__position[] = "position";
static char control_msgs__action__SingleJointPosition_Feedback__FIELD_NAME__velocity[] = "velocity";
static char control_msgs__action__SingleJointPosition_Feedback__FIELD_NAME__error[] = "error";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_Feedback__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_Feedback__FIELD_NAME__header, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Feedback__FIELD_NAME__position, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_DOUBLE,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Feedback__FIELD_NAME__velocity, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_DOUBLE,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Feedback__FIELD_NAME__error, 5, 5},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_DOUBLE,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_Feedback__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_Feedback__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_Feedback__TYPE_NAME, 48, 48},
      {control_msgs__action__SingleJointPosition_Feedback__FIELDS, 4, 4},
    },
    {control_msgs__action__SingleJointPosition_Feedback__REFERENCED_TYPE_DESCRIPTIONS, 2, 2},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_SendGoal__FIELD_NAME__request_message[] = "request_message";
static char control_msgs__action__SingleJointPosition_SendGoal__FIELD_NAME__response_message[] = "response_message";
static char control_msgs__action__SingleJointPosition_SendGoal__FIELD_NAME__event_message[] = "event_message";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_SendGoal__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_SendGoal__FIELD_NAME__request_message, 15, 15},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_SendGoal_Request__TYPE_NAME, 56, 56},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal__FIELD_NAME__response_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_SendGoal_Response__TYPE_NAME, 57, 57},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal__FIELD_NAME__event_message, 13, 13},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_SendGoal_Event__TYPE_NAME, 54, 54},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_SendGoal__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Goal__TYPE_NAME, 44, 44},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Event__TYPE_NAME, 54, 54},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Request__TYPE_NAME, 56, 56},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Response__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_SendGoal__get_type_description(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_SendGoal__TYPE_NAME, 48, 48},
      {control_msgs__action__SingleJointPosition_SendGoal__FIELDS, 3, 3},
    },
    {control_msgs__action__SingleJointPosition_SendGoal__REFERENCED_TYPE_DESCRIPTIONS, 8, 8},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__SingleJointPosition_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__SingleJointPosition_SendGoal_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = control_msgs__action__SingleJointPosition_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[5].fields = control_msgs__action__SingleJointPosition_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[7].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_SendGoal_Request__FIELD_NAME__goal_id[] = "goal_id";
static char control_msgs__action__SingleJointPosition_SendGoal_Request__FIELD_NAME__goal[] = "goal";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_SendGoal_Request__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Request__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Request__FIELD_NAME__goal, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_Goal__TYPE_NAME, 44, 44},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_SendGoal_Request__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Goal__TYPE_NAME, 44, 44},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_SendGoal_Request__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_SendGoal_Request__TYPE_NAME, 56, 56},
      {control_msgs__action__SingleJointPosition_SendGoal_Request__FIELDS, 2, 2},
    },
    {control_msgs__action__SingleJointPosition_SendGoal_Request__REFERENCED_TYPE_DESCRIPTIONS, 3, 3},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__SingleJointPosition_Goal__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_SendGoal_Response__FIELD_NAME__accepted[] = "accepted";
static char control_msgs__action__SingleJointPosition_SendGoal_Response__FIELD_NAME__stamp[] = "stamp";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_SendGoal_Response__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Response__FIELD_NAME__accepted, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_BOOLEAN,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Response__FIELD_NAME__stamp, 5, 5},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_SendGoal_Response__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_SendGoal_Response__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_SendGoal_Response__TYPE_NAME, 57, 57},
      {control_msgs__action__SingleJointPosition_SendGoal_Response__FIELDS, 2, 2},
    },
    {control_msgs__action__SingleJointPosition_SendGoal_Response__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_SendGoal_Event__FIELD_NAME__info[] = "info";
static char control_msgs__action__SingleJointPosition_SendGoal_Event__FIELD_NAME__request[] = "request";
static char control_msgs__action__SingleJointPosition_SendGoal_Event__FIELD_NAME__response[] = "response";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_SendGoal_Event__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Event__FIELD_NAME__info, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Event__FIELD_NAME__request, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {control_msgs__action__SingleJointPosition_SendGoal_Request__TYPE_NAME, 56, 56},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Event__FIELD_NAME__response, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {control_msgs__action__SingleJointPosition_SendGoal_Response__TYPE_NAME, 57, 57},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_SendGoal_Event__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Duration__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Goal__TYPE_NAME, 44, 44},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Request__TYPE_NAME, 56, 56},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_SendGoal_Response__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_SendGoal_Event__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_SendGoal_Event__TYPE_NAME, 54, 54},
      {control_msgs__action__SingleJointPosition_SendGoal_Event__FIELDS, 3, 3},
    },
    {control_msgs__action__SingleJointPosition_SendGoal_Event__REFERENCED_TYPE_DESCRIPTIONS, 7, 7},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Duration__EXPECTED_HASH, builtin_interfaces__msg__Duration__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Duration__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[1].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__SingleJointPosition_Goal__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__SingleJointPosition_SendGoal_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = control_msgs__action__SingleJointPosition_SendGoal_Response__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_GetResult__FIELD_NAME__request_message[] = "request_message";
static char control_msgs__action__SingleJointPosition_GetResult__FIELD_NAME__response_message[] = "response_message";
static char control_msgs__action__SingleJointPosition_GetResult__FIELD_NAME__event_message[] = "event_message";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_GetResult__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_GetResult__FIELD_NAME__request_message, 15, 15},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_GetResult_Request__TYPE_NAME, 57, 57},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult__FIELD_NAME__response_message, 16, 16},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_GetResult_Response__TYPE_NAME, 58, 58},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult__FIELD_NAME__event_message, 13, 13},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_GetResult_Event__TYPE_NAME, 55, 55},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_GetResult__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Event__TYPE_NAME, 55, 55},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Request__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Response__TYPE_NAME, 58, 58},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Result__TYPE_NAME, 46, 46},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_GetResult__get_type_description(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_GetResult__TYPE_NAME, 49, 49},
      {control_msgs__action__SingleJointPosition_GetResult__FIELDS, 3, 3},
    },
    {control_msgs__action__SingleJointPosition_GetResult__REFERENCED_TYPE_DESCRIPTIONS, 7, 7},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__SingleJointPosition_GetResult_Event__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__SingleJointPosition_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__SingleJointPosition_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[4].fields = control_msgs__action__SingleJointPosition_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[6].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_GetResult_Request__FIELD_NAME__goal_id[] = "goal_id";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_GetResult_Request__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_GetResult_Request__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_GetResult_Request__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_GetResult_Request__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_GetResult_Request__TYPE_NAME, 57, 57},
      {control_msgs__action__SingleJointPosition_GetResult_Request__FIELDS, 1, 1},
    },
    {control_msgs__action__SingleJointPosition_GetResult_Request__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_GetResult_Response__FIELD_NAME__status[] = "status";
static char control_msgs__action__SingleJointPosition_GetResult_Response__FIELD_NAME__result[] = "result";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_GetResult_Response__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_GetResult_Response__FIELD_NAME__status, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_INT8,
      0,
      0,
      {NULL, 0, 0},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Response__FIELD_NAME__result, 6, 6},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_Result__TYPE_NAME, 46, 46},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_GetResult_Response__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {control_msgs__action__SingleJointPosition_Result__TYPE_NAME, 46, 46},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_GetResult_Response__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_GetResult_Response__TYPE_NAME, 58, 58},
      {control_msgs__action__SingleJointPosition_GetResult_Response__FIELDS, 2, 2},
    },
    {control_msgs__action__SingleJointPosition_GetResult_Response__REFERENCED_TYPE_DESCRIPTIONS, 1, 1},
  };
  if (!constructed) {
    description.referenced_type_descriptions.data[0].fields = control_msgs__action__SingleJointPosition_Result__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_GetResult_Event__FIELD_NAME__info[] = "info";
static char control_msgs__action__SingleJointPosition_GetResult_Event__FIELD_NAME__request[] = "request";
static char control_msgs__action__SingleJointPosition_GetResult_Event__FIELD_NAME__response[] = "response";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_GetResult_Event__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_GetResult_Event__FIELD_NAME__info, 4, 4},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Event__FIELD_NAME__request, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {control_msgs__action__SingleJointPosition_GetResult_Request__TYPE_NAME, 57, 57},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Event__FIELD_NAME__response, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE_BOUNDED_SEQUENCE,
      1,
      0,
      {control_msgs__action__SingleJointPosition_GetResult_Response__TYPE_NAME, 58, 58},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_GetResult_Event__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Request__TYPE_NAME, 57, 57},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_GetResult_Response__TYPE_NAME, 58, 58},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Result__TYPE_NAME, 46, 46},
    {NULL, 0, 0},
  },
  {
    {service_msgs__msg__ServiceEventInfo__TYPE_NAME, 33, 33},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_GetResult_Event__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_GetResult_Event__TYPE_NAME, 55, 55},
      {control_msgs__action__SingleJointPosition_GetResult_Event__FIELDS, 3, 3},
    },
    {control_msgs__action__SingleJointPosition_GetResult_Event__REFERENCED_TYPE_DESCRIPTIONS, 6, 6},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__SingleJointPosition_GetResult_Request__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[2].fields = control_msgs__action__SingleJointPosition_GetResult_Response__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[3].fields = control_msgs__action__SingleJointPosition_Result__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&service_msgs__msg__ServiceEventInfo__EXPECTED_HASH, service_msgs__msg__ServiceEventInfo__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[4].fields = service_msgs__msg__ServiceEventInfo__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[5].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}
// Define type names, field names, and default values
static char control_msgs__action__SingleJointPosition_FeedbackMessage__FIELD_NAME__goal_id[] = "goal_id";
static char control_msgs__action__SingleJointPosition_FeedbackMessage__FIELD_NAME__feedback[] = "feedback";

static rosidl_runtime_c__type_description__Field control_msgs__action__SingleJointPosition_FeedbackMessage__FIELDS[] = {
  {
    {control_msgs__action__SingleJointPosition_FeedbackMessage__FIELD_NAME__goal_id, 7, 7},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    },
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_FeedbackMessage__FIELD_NAME__feedback, 8, 8},
    {
      rosidl_runtime_c__type_description__FieldType__FIELD_TYPE_NESTED_TYPE,
      0,
      0,
      {control_msgs__action__SingleJointPosition_Feedback__TYPE_NAME, 48, 48},
    },
    {NULL, 0, 0},
  },
};

static rosidl_runtime_c__type_description__IndividualTypeDescription control_msgs__action__SingleJointPosition_FeedbackMessage__REFERENCED_TYPE_DESCRIPTIONS[] = {
  {
    {builtin_interfaces__msg__Time__TYPE_NAME, 27, 27},
    {NULL, 0, 0},
  },
  {
    {control_msgs__action__SingleJointPosition_Feedback__TYPE_NAME, 48, 48},
    {NULL, 0, 0},
  },
  {
    {std_msgs__msg__Header__TYPE_NAME, 19, 19},
    {NULL, 0, 0},
  },
  {
    {unique_identifier_msgs__msg__UUID__TYPE_NAME, 31, 31},
    {NULL, 0, 0},
  },
};

const rosidl_runtime_c__type_description__TypeDescription *
control_msgs__action__SingleJointPosition_FeedbackMessage__get_type_description(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static bool constructed = false;
  static const rosidl_runtime_c__type_description__TypeDescription description = {
    {
      {control_msgs__action__SingleJointPosition_FeedbackMessage__TYPE_NAME, 55, 55},
      {control_msgs__action__SingleJointPosition_FeedbackMessage__FIELDS, 2, 2},
    },
    {control_msgs__action__SingleJointPosition_FeedbackMessage__REFERENCED_TYPE_DESCRIPTIONS, 4, 4},
  };
  if (!constructed) {
    assert(0 == memcmp(&builtin_interfaces__msg__Time__EXPECTED_HASH, builtin_interfaces__msg__Time__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[0].fields = builtin_interfaces__msg__Time__get_type_description(NULL)->type_description.fields;
    description.referenced_type_descriptions.data[1].fields = control_msgs__action__SingleJointPosition_Feedback__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&std_msgs__msg__Header__EXPECTED_HASH, std_msgs__msg__Header__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[2].fields = std_msgs__msg__Header__get_type_description(NULL)->type_description.fields;
    assert(0 == memcmp(&unique_identifier_msgs__msg__UUID__EXPECTED_HASH, unique_identifier_msgs__msg__UUID__get_type_hash(NULL), sizeof(rosidl_type_hash_t)));
    description.referenced_type_descriptions.data[3].fields = unique_identifier_msgs__msg__UUID__get_type_description(NULL)->type_description.fields;
    constructed = true;
  }
  return &description;
}

static char toplevel_type_raw_source[] =
  "float64 position\n"
  "builtin_interfaces/Duration min_duration\n"
  "float64 max_velocity\n"
  "---\n"
  "---\n"
  "std_msgs/Header header\n"
  "float64 position\n"
  "float64 velocity\n"
  "float64 error";

static char action_encoding[] = "action";
static char implicit_encoding[] = "implicit";

// Define all individual source functions

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition__get_individual_type_description_source(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition__TYPE_NAME, 39, 39},
    {action_encoding, 6, 6},
    {toplevel_type_raw_source, 158, 158},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_Goal__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_Goal__TYPE_NAME, 44, 44},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_Result__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_Result__TYPE_NAME, 46, 46},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_Feedback__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_Feedback__TYPE_NAME, 48, 48},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_SendGoal__get_individual_type_description_source(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_SendGoal__TYPE_NAME, 48, 48},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_SendGoal_Request__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_SendGoal_Request__TYPE_NAME, 56, 56},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_SendGoal_Response__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_SendGoal_Response__TYPE_NAME, 57, 57},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_SendGoal_Event__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_SendGoal_Event__TYPE_NAME, 54, 54},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_GetResult__get_individual_type_description_source(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_GetResult__TYPE_NAME, 49, 49},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_GetResult_Request__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_GetResult_Request__TYPE_NAME, 57, 57},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_GetResult_Response__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_GetResult_Response__TYPE_NAME, 58, 58},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_GetResult_Event__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_GetResult_Event__TYPE_NAME, 55, 55},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource *
control_msgs__action__SingleJointPosition_FeedbackMessage__get_individual_type_description_source(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static const rosidl_runtime_c__type_description__TypeSource source = {
    {control_msgs__action__SingleJointPosition_FeedbackMessage__TYPE_NAME, 55, 55},
    {implicit_encoding, 8, 8},
    {NULL, 0, 0},
  };
  return &source;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition__get_type_description_sources(
  const rosidl_action_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[18];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 18, 18};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__SingleJointPosition_Feedback__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__SingleJointPosition_FeedbackMessage__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__action__SingleJointPosition_GetResult__get_individual_type_description_source(NULL);
    sources[6] = *control_msgs__action__SingleJointPosition_GetResult_Event__get_individual_type_description_source(NULL);
    sources[7] = *control_msgs__action__SingleJointPosition_GetResult_Request__get_individual_type_description_source(NULL);
    sources[8] = *control_msgs__action__SingleJointPosition_GetResult_Response__get_individual_type_description_source(NULL);
    sources[9] = *control_msgs__action__SingleJointPosition_Goal__get_individual_type_description_source(NULL);
    sources[10] = *control_msgs__action__SingleJointPosition_Result__get_individual_type_description_source(NULL);
    sources[11] = *control_msgs__action__SingleJointPosition_SendGoal__get_individual_type_description_source(NULL);
    sources[12] = *control_msgs__action__SingleJointPosition_SendGoal_Event__get_individual_type_description_source(NULL);
    sources[13] = *control_msgs__action__SingleJointPosition_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[14] = *control_msgs__action__SingleJointPosition_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[15] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[16] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[17] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_Goal__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_Goal__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_Result__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[1];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 1, 1};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_Result__get_individual_type_description_source(NULL),
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_Feedback__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[3];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 3, 3};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_Feedback__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_SendGoal__get_type_description_sources(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[9];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 9, 9};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_SendGoal__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__SingleJointPosition_Goal__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__SingleJointPosition_SendGoal_Event__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__action__SingleJointPosition_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[6] = *control_msgs__action__SingleJointPosition_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[7] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[8] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_SendGoal_Request__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[4];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 4, 4};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_SendGoal_Request__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__SingleJointPosition_Goal__get_individual_type_description_source(NULL);
    sources[3] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_SendGoal_Response__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_SendGoal_Response__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_SendGoal_Event__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[8];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 8, 8};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_SendGoal_Event__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Duration__get_individual_type_description_source(NULL);
    sources[2] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__SingleJointPosition_Goal__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__SingleJointPosition_SendGoal_Request__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__action__SingleJointPosition_SendGoal_Response__get_individual_type_description_source(NULL);
    sources[6] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[7] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_GetResult__get_type_description_sources(
  const rosidl_service_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[8];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 8, 8};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_GetResult__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__SingleJointPosition_GetResult_Event__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__SingleJointPosition_GetResult_Request__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__SingleJointPosition_GetResult_Response__get_individual_type_description_source(NULL);
    sources[5] = *control_msgs__action__SingleJointPosition_Result__get_individual_type_description_source(NULL);
    sources[6] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[7] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_GetResult_Request__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_GetResult_Request__get_individual_type_description_source(NULL),
    sources[1] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_GetResult_Response__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[2];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 2, 2};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_GetResult_Response__get_individual_type_description_source(NULL),
    sources[1] = *control_msgs__action__SingleJointPosition_Result__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_GetResult_Event__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[7];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 7, 7};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_GetResult_Event__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__SingleJointPosition_GetResult_Request__get_individual_type_description_source(NULL);
    sources[3] = *control_msgs__action__SingleJointPosition_GetResult_Response__get_individual_type_description_source(NULL);
    sources[4] = *control_msgs__action__SingleJointPosition_Result__get_individual_type_description_source(NULL);
    sources[5] = *service_msgs__msg__ServiceEventInfo__get_individual_type_description_source(NULL);
    sources[6] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}

const rosidl_runtime_c__type_description__TypeSource__Sequence *
control_msgs__action__SingleJointPosition_FeedbackMessage__get_type_description_sources(
  const rosidl_message_type_support_t * type_support)
{
  (void)type_support;
  static rosidl_runtime_c__type_description__TypeSource sources[5];
  static const rosidl_runtime_c__type_description__TypeSource__Sequence source_sequence = {sources, 5, 5};
  static bool constructed = false;
  if (!constructed) {
    sources[0] = *control_msgs__action__SingleJointPosition_FeedbackMessage__get_individual_type_description_source(NULL),
    sources[1] = *builtin_interfaces__msg__Time__get_individual_type_description_source(NULL);
    sources[2] = *control_msgs__action__SingleJointPosition_Feedback__get_individual_type_description_source(NULL);
    sources[3] = *std_msgs__msg__Header__get_individual_type_description_source(NULL);
    sources[4] = *unique_identifier_msgs__msg__UUID__get_individual_type_description_source(NULL);
    constructed = true;
  }
  return &source_sequence;
}
