// generated from rosidl_generator_c/resource/idl.h.em
// with input from control_msgs:srv/SetOdometry.idl
// generated code does not contain a copyright notice

#ifndef CONTROL_MSGS__SRV__SET_ODOMETRY_H_
#define CONTROL_MSGS__SRV__SET_ODOMETRY_H_

#include "control_msgs/srv/detail/set_odometry__struct.h"
#include "control_msgs/srv/detail/set_odometry__functions.h"
#include "control_msgs/srv/detail/set_odometry__type_support.h"

#endif  // CONTROL_MSGS__SRV__SET_ODOMETRY_H_
