// generated from rosidl_adapter/resource/msg.idl.em
// with input from control_msgs/msg/DynamicInterfaceValues.msg
// generated code does not contain a copyright notice

#include "control_msgs/msg/InterfaceValue.idl"
#include "std_msgs/msg/Header.idl"

module control_msgs {
  module msg {
    struct DynamicInterfaceValues {
      std_msgs::msg::Header header;

      control_msgs::msg::InterfaceValue states;

      control_msgs::msg::InterfaceValue commands;
    };
  };
};
